SmartCacheBase class abstract

Constructors

SmartCacheBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
Wipes the entire cache.
get<T>({required String key}) → Future<T?>
Retrieves a value from the cache by its key.
init() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put<T>({Duration? expiry, required String key, T? data}) → Future<void>
Saves data to the cache and persists it to the disk.
remove({required String key}) → Future<void>
Removes a specific item from the cache.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited