SmartCacheConfig class

Constructors

SmartCacheConfig({int maxObjects = 100, Duration defaultExpiry = const Duration(hours: 1), EvictionStrategy strategy = EvictionStrategy.lru, bool isPersistent = false, bool useRam = false})

Properties

defaultExpiry → Duration
The default duration for which an item remains valid.
final
hashCode → int
The hash code for this object.
no setterinherited
isPersistent → bool
Determines where the file cache is stored on the device.
final
maxObjects → int
The maximum number of items allowed in the cache.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strategy → EvictionStrategy
The eviction policy to use when maxObjects is reached.
final
useRam → bool
Determines the storage engine used.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited